==> api-0.21.0-sources.jar: io/strimzi/api/kafka/model/AbstractKafkaConnectSpecFluent.java <==
package io.strimzi.api.kafka.model;

import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ResourceRequirements;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.util.LinkedHashMap;
import java.util.List;
import java.lang.Boolean;
import io.strimzi.api.kafka.model.connect.ExternalConfigurationFluent;
import io.strimzi.api.kafka.model.template.KafkaConnectTemplateFluent;
import io.strimzi.api.kafka.model.connect.ExternalConfigurationBuilder;
import io.strimzi.api.kafka.model.tracing.JaegerTracingFluent;
import io.fabric8.kubernetes.api.model.Toleration;
import java.lang.Long;
import io.fabric8.kubernetes.api.model.Affinity;
import java.util.Collection;
import java.lang.Object;
import io.strimzi.api.kafka.model.tracing.Tracing;
import java.util.Map;
import io.strimzi.api.kafka.model.template.KafkaConnectTemplateBuilder;
import io.strimzi.api.kafka.model.tracing.JaegerTracingBuilder;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import io.strimzi.api.kafka.model.template.KafkaConnectTemplate;
import java.lang.Deprecated;
import io.strimzi.api.kafka.model.tracing.JaegerTracing;
import java.lang.Integer;
import java.lang.StringBuffer;
import io.strimzi.api.kafka.model.connect.ExternalConfiguration;

public interface AbstractKafkaConnectSpecFluent<A extends AbstractKafkaConnectSpecFluent<A>> extends SpecFluent<A>{


    
/**
 * This method has been deprecated, please use method buildLogging instead.
 * @return The buildable object.
 */
@Deprecated public Logging getLogging();
    public Logging buildLogging();
    public A withLogging(Logging logging);
    public Boolean hasLogging();
    public A withExternalLogging(ExternalLogging externalLogging);
    public AbstractKafkaConnectSpecFluent.ExternalLoggingNested<A> withNewExternalLogging();
    public AbstractKafkaConnectSpecFluent.ExternalLoggingNested<A> withNewExternalLoggingLike(ExternalLogging item);
    public A withInlineLogging(InlineLogging inlineLogging);
    public AbstractKafkaConnectSpecFluent.InlineLoggingNested<A> withNewInlineLogging();
    public AbstractKafkaConnectSpecFluent.InlineLoggingNested<A> withNewInlineLoggingLike(InlineLogging item);
    public Integer getReplicas();
    public A withReplicas(Integer replicas);
    public Boolean hasReplicas();
    public String getVersion();
    public A withVersion(String version);
    public Boolean hasVersion();
    public A withNewVersion(String arg1);
    public A withNewVersion(StringBuilder arg1);
    public A withNewVersion(StringBuffer arg1);
    public String getImage();
    public A withImage(String image);
    public Boolean hasImage();
    public A withNewImage(String arg1);
    public A withNewImage(StringBuilder arg1);
    public A withNewImage(StringBuffer arg1);
    public ResourceRequirements getResources();
    public A withResources(ResourceRequirements resources);
    public Boolean hasResources();
    
/**
 * This method has been deprecated, please use method buildLivenessProbe instead.
 * @return The buildable object.
 */
@Deprecated public Probe getLivenessProbe();
    public Probe buildLivenessProbe();
    public A withLivenessProbe(Probe livenessProbe);
    public Boolean hasLivenessProbe();
    public A withNewLivenessProbe(int initialDelaySeconds,int timeoutSeconds);
    public AbstractKafkaConnectSpecFluent.LivenessProbeNested<A> withNewLivenessProbe();
    public AbstractKafkaConnectSpecFluent.LivenessProbeNested<A> withNewLivenessProbeLike(Probe item);
    public AbstractKafkaConnectSpecFluent.LivenessProbeNested<A> editLivenessProbe();
    public AbstractKafkaConnectSpecFluent.LivenessProbeNested<A> editOrNewLivenessProbe();
    public AbstractKafkaConnectSpecFluent.LivenessProbeNested<A> editOrNewLivenessProbeLike(Probe item);
    
/**
 * This method has been deprecated, please use method buildReadinessProbe instead.
 * @return The buildable object.
 */
@Deprecated public Probe getReadinessProbe();
    public Probe buildReadinessProbe();
    public A withReadinessProbe(Probe readinessProbe);
    public Boolean hasReadinessProbe();
    public A withNewReadinessProbe(int initialDelaySeconds,int timeoutSeconds);
    public AbstractKafkaConnectSpecFluent.ReadinessProbeNested<A> withNewReadinessProbe();
    public AbstractKafkaConnectSpecFluent.ReadinessProbeNested<A> withNewReadinessProbeLike(Probe item);
    public AbstractKafkaConnectSpecFluent.ReadinessProbeNested<A> editReadinessProbe();
    public AbstractKafkaConnectSpecFluent.ReadinessProbeNested<A> editOrNewReadinessProbe();
    public AbstractKafkaConnectSpecFluent.ReadinessProbeNested<A> editOrNewReadinessProbeLike(Probe item);
    
/**
 * This method has been deprecated, please use method buildJvmOptions instead.
 * @return The buildable object.
 */
@Deprecated public JvmOptions getJvmOptions();
    public JvmOptions buildJvmOptions();
    public A withJvmOptions(JvmOptions jvmOptions);
    public Boolean hasJvmOptions();
    public AbstractKafkaConnectSpecFluent.JvmOptionsNested<A> withNewJvmOptions();
    public AbstractKafkaConnectSpecFluent.JvmOptionsNested<A> withNewJvmOptionsLike(JvmOptions item);
    public AbstractKafkaConnectSpecFluent.JvmOptionsNested<A> editJvmOptions();
    public AbstractKafkaConnectSpecFluent.JvmOptionsNested<A> editOrNewJvmOptions();
    public AbstractKafkaConnectSpecFluent.JvmOptionsNested<A> editOrNewJvmOptionsLike(JvmOptions item);
    
/**
 * This method has been deprecated, please use method buildMetricsConfig instead.
 * @return The buildable object.
 */
@Deprecated public MetricsConfig getMetricsConfig();
    public MetricsConfig buildMetricsConfig();
    public A withMetricsConfig(MetricsConfig metricsConfig);
    public Boolean hasMetricsConfig();
    public A withJmxPrometheusExporterMetricsConfig(JmxPrometheusExporterMetrics jmxPrometheusExporterMetricsConfig);
    public AbstractKafkaConnectSpecFluent.JmxPrometheusExporterMetricsConfigNested<A> withNewJmxPrometheusExporterMetricsConfig();
    public AbstractKafkaConnectSpecFluent.JmxPrometheusExporterMetricsConfigNested<A> withNewJmxPrometheusExporterMetricsConfigLike(JmxPrometheusExporterMetrics item);
    public A addToMetrics(String key,Object value);
    public A addToMetrics(Map<String,Object> map);
    public A removeFromMetrics(String key);
    public A removeFromMetrics(Map<String,Object> map);
    public Map<String,Object> getMetrics();
    public A withMetrics(Map<String,Object> metrics);
    public Boolean hasMetrics();
    
/**
 * This method has been deprecated, please use method buildTracing instead.
 * @return The buildable object.
 */
@Deprecated public Tracing getTracing();
    public Tracing buildTracing();
    public A withTracing(Tracing tracing);
    public Boolean hasTracing();
    public A withJaegerTracing(JaegerTracing jaegerTracing);
    public AbstractKafkaConnectSpecFluent.JaegerTracingNested<A> withNewJaegerTracing();
    public AbstractKafkaConnectSpecFluent.JaegerTracingNested<A> withNewJaegerTracingLike(JaegerTracing item);
    public Affinity getAffinity();
    public A withAffinity(Affinity affinity);
    public Boolean hasAffinity();
    public A addToTolerations(int index,Toleration item);
    public A setToTolerations(int index,Toleration item);
    public A addToTolerations(Toleration... items);
    public A addAllToTolerations(Collection<Toleration> items);
    public A removeFromTolerations(Toleration... items);
    public A removeAllFromTolerations(Collection<Toleration> items);
    public java.util.List<Toleration> getTolerations();
    public Toleration getToleration(int index);
    public Toleration getFirstToleration();
    public Toleration getLastToleration();
    public Toleration getMatchingToleration(io.fabric8.kubernetes.api.builder.Predicate<Toleration> predicate);
    public Boolean hasMatchingToleration(io.fabric8.kubernetes.api.builder.Predicate<Toleration> predicate);
    public A withTolerations(java.util.List<Toleration> tolerations);
    public A withTolerations(Toleration... tolerations);
    public Boolean hasTolerations();
    public A addNewToleration(String effect,String key,String operator,Long tolerationSeconds,String value);
    
/**
 * This method has been deprecated, please use method buildTemplate instead.
 * @return The buildable object.
 */
@Deprecated public KafkaConnectTemplate getTemplate();
    public KafkaConnectTemplate buildTemplate();
    public A withTemplate(KafkaConnectTemplate template);
    public Boolean hasTemplate();
    public AbstractKafkaConnectSpecFluent.TemplateNested<A> withNewTemplate();
    public AbstractKafkaConnectSpecFluent.TemplateNested<A> withNewTemplateLike(KafkaConnectTemplate item);
    public AbstractKafkaConnectSpecFluent.TemplateNested<A> editTemplate();
    public AbstractKafkaConnectSpecFluent.TemplateNested<A> editOrNewTemplate();
    public AbstractKafkaConnectSpecFluent.TemplateNested<A> editOrNewTemplateLike(KafkaConnectTemplate item);
    
/**
 * This method has been deprecated, please use method buildExternalConfiguration instead.
 * @return The buildable object.
 */
@Deprecated public ExternalConfiguration getExternalConfiguration();
    public ExternalConfiguration buildExternalConfiguration();
    public A withExternalConfiguration(ExternalConfiguration externalConfiguration);
    public Boolean hasExternalConfiguration();
    public AbstractKafkaConnectSpecFluent.ExternalConfigurationNested<A> withNewExternalConfiguration();
    public AbstractKafkaConnectSpecFluent.ExternalConfigurationNested<A> withNewExternalConfigurationLike(ExternalConfiguration item);
    public AbstractKafkaConnectSpecFluent.ExternalConfigurationNested<A> editExternalConfiguration();
    public AbstractKafkaConnectSpecFluent.ExternalConfigurationNested<A> editOrNewExternalConfiguration();
    public AbstractKafkaConnectSpecFluent.ExternalConfigurationNested<A> editOrNewExternalConfigurationLike(ExternalConfiguration item);

    public interface ExternalLoggingNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ExternalLoggingFluent<AbstractKafkaConnectSpecFluent.ExternalLoggingNested<N>>{

        
    public N and();    public N endExternalLogging();
}
    public interface InlineLoggingNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,InlineLoggingFluent<AbstractKafkaConnectSpecFluent.InlineLoggingNested<N>>{

        
    public N and();    public N endInlineLogging();
}
    public interface LivenessProbeNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ProbeFluent<AbstractKafkaConnectSpecFluent.LivenessProbeNested<N>>{

        
    public N and();    public N endLivenessProbe();
}
    public interface ReadinessProbeNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ProbeFluent<AbstractKafkaConnectSpecFluent.ReadinessProbeNested<N>>{

        
    public N and();    public N endReadinessProbe();
}
    public interface JvmOptionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,JvmOptionsFluent<AbstractKafkaConnectSpecFluent.JvmOptionsNested<N>>{

        
    public N and();    public N endJvmOptions();
}
    public interface JmxPrometheusExporterMetricsConfigNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,JmxPrometheusExporterMetricsFluent<AbstractKafkaConnectSpecFluent.JmxPrometheusExporterMetricsConfigNested<N>>{

        
    public N and();    public N endJmxPrometheusExporterMetricsConfig();
}
    public interface JaegerTracingNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,JaegerTracingFluent<AbstractKafkaConnectSpecFluent.JaegerTracingNested<N>>{

        
    public N and();    public N endJaegerTracing();
}
    public interface TemplateNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaConnectTemplateFluent<AbstractKafkaConnectSpecFluent.TemplateNested<N>>{

        
    public N and();    public N endTemplate();
}
    public interface ExternalConfigurationNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ExternalConfigurationFluent<AbstractKafkaConnectSpecFluent.ExternalConfigurationNested<N>>{

        
    public N and();    public N endExternalConfiguration();
}


}

==> api-0.23.0-sources.jar: io/strimzi/api/kafka/model/AbstractKafkaConnectSpecFluent.java <==
package io.strimzi.api.kafka.model;

import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ResourceRequirements;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.util.List;
import java.lang.Boolean;
import io.strimzi.api.kafka.model.connect.ExternalConfigurationFluent;
import io.strimzi.api.kafka.model.template.KafkaConnectTemplateFluent;
import io.strimzi.api.kafka.model.connect.ExternalConfigurationBuilder;
import io.strimzi.api.kafka.model.tracing.JaegerTracingFluent;
import io.fabric8.kubernetes.api.model.Toleration;
import java.lang.Long;
import io.fabric8.kubernetes.api.model.Affinity;
import java.util.Collection;
import java.lang.Object;
import io.strimzi.api.kafka.model.tracing.Tracing;
import java.util.Map;
import io.strimzi.api.kafka.model.template.KafkaConnectTemplateBuilder;
import io.strimzi.api.kafka.model.tracing.JaegerTracingBuilder;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import io.strimzi.api.kafka.model.template.KafkaConnectTemplate;
import java.lang.Deprecated;
import io.strimzi.api.kafka.model.tracing.JaegerTracing;
import java.lang.Integer;
import java.lang.StringBuffer;
import io.strimzi.api.kafka.model.connect.ExternalConfiguration;

public interface AbstractKafkaConnectSpecFluent<A extends AbstractKafkaConnectSpecFluent<A>> extends SpecFluent<A> {


    
/**
 * This method has been deprecated, please use method buildLogging instead.
 * @return The buildable object.
 */
@Deprecated public Logging getLogging();
    public Logging buildLogging();
    public A withLogging(Logging logging);
    public Boolean hasLogging();
    public A withExternalLogging(ExternalLogging externalLogging);
    public AbstractKafkaConnectSpecFluent.ExternalLoggingNested<A> withNewExternalLogging();
    public AbstractKafkaConnectSpecFluent.ExternalLoggingNested<A> withNewExternalLoggingLike(ExternalLogging item);
    public A withInlineLogging(InlineLogging inlineLogging);
    public AbstractKafkaConnectSpecFluent.InlineLoggingNested<A> withNewInlineLogging();
    public AbstractKafkaConnectSpecFluent.InlineLoggingNested<A> withNewInlineLoggingLike(InlineLogging item);
    public Integer getReplicas();
    public A withReplicas(Integer replicas);
    public Boolean hasReplicas();
    public String getVersion();
    public A withVersion(String version);
    public Boolean hasVersion();
    public A withNewVersion(StringBuilder arg1);
    public A withNewVersion(int[] arg1,int arg2,int arg3);
    public A withNewVersion(char[] arg1);
    public A withNewVersion(StringBuffer arg1);
    public A withNewVersion(byte[] arg1,int arg2);
    public A withNewVersion(byte[] arg1);
    public A withNewVersion(char[] arg1,int arg2,int arg3);
    public A withNewVersion(byte[] arg1,int arg2,int arg3);
    public A withNewVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewVersion(String arg1);
    public String getImage();
    public A withImage(String image);
    public Boolean hasImage();
    public A withNewImage(StringBuilder arg1);
    public A withNewImage(int[] arg1,int arg2,int arg3);
    public A withNewImage(char[] arg1);
    public A withNewImage(StringBuffer arg1);
    public A withNewImage(byte[] arg1,int arg2);
    public A withNewImage(byte[] arg1);
    public A withNewImage(char[] arg1,int arg2,int arg3);
    public A withNewImage(byte[] arg1,int arg2,int arg3);
    public A withNewImage(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewImage(String arg1);
    public ResourceRequirements getResources();
    public A withResources(ResourceRequirements resources);
    public Boolean hasResources();
    
/**
 * This method has been deprecated, please use method buildLivenessProbe instead.
 * @return The buildable object.
 */
@Deprecated public Probe getLivenessProbe();
    public Probe buildLivenessProbe();
    public A withLivenessProbe(Probe livenessProbe);
    public Boolean hasLivenessProbe();
    public A withNewLivenessProbe(int initialDelaySeconds,int timeoutSeconds);
    public AbstractKafkaConnectSpecFluent.LivenessProbeNested<A> withNewLivenessProbe();
    public AbstractKafkaConnectSpecFluent.LivenessProbeNested<A> withNewLivenessProbeLike(Probe item);
    public AbstractKafkaConnectSpecFluent.LivenessProbeNested<A> editLivenessProbe();
    public AbstractKafkaConnectSpecFluent.LivenessProbeNested<A> editOrNewLivenessProbe();
    public AbstractKafkaConnectSpecFluent.LivenessProbeNested<A> editOrNewLivenessProbeLike(Probe item);
    
/**
 * This method has been deprecated, please use method buildReadinessProbe instead.
 * @return The buildable object.
 */
@Deprecated public Probe getReadinessProbe();
    public Probe buildReadinessProbe();
    public A withReadinessProbe(Probe readinessProbe);
    public Boolean hasReadinessProbe();
    public A withNewReadinessProbe(int initialDelaySeconds,int timeoutSeconds);
    public AbstractKafkaConnectSpecFluent.ReadinessProbeNested<A> withNewReadinessProbe();
    public AbstractKafkaConnectSpecFluent.ReadinessProbeNested<A> withNewReadinessProbeLike(Probe item);
    public AbstractKafkaConnectSpecFluent.ReadinessProbeNested<A> editReadinessProbe();
    public AbstractKafkaConnectSpecFluent.ReadinessProbeNested<A> editOrNewReadinessProbe();
    public AbstractKafkaConnectSpecFluent.ReadinessProbeNested<A> editOrNewReadinessProbeLike(Probe item);
    
/**
 * This method has been deprecated, please use method buildJmxOptions instead.
 * @return The buildable object.
 */
@Deprecated public KafkaJmxOptions getJmxOptions();
    public KafkaJmxOptions buildJmxOptions();
    public A withJmxOptions(KafkaJmxOptions jmxOptions);
    public Boolean hasJmxOptions();
    public AbstractKafkaConnectSpecFluent.JmxOptionsNested<A> withNewJmxOptions();
    public AbstractKafkaConnectSpecFluent.JmxOptionsNested<A> withNewJmxOptionsLike(KafkaJmxOptions item);
    public AbstractKafkaConnectSpecFluent.JmxOptionsNested<A> editJmxOptions();
    public AbstractKafkaConnectSpecFluent.JmxOptionsNested<A> editOrNewJmxOptions();
    public AbstractKafkaConnectSpecFluent.JmxOptionsNested<A> editOrNewJmxOptionsLike(KafkaJmxOptions item);
    
/**
 * This method has been deprecated, please use method buildJvmOptions instead.
 * @return The buildable object.
 */
@Deprecated public JvmOptions getJvmOptions();
    public JvmOptions buildJvmOptions();
    public A withJvmOptions(JvmOptions jvmOptions);
    public Boolean hasJvmOptions();
    public AbstractKafkaConnectSpecFluent.JvmOptionsNested<A> withNewJvmOptions();
    public AbstractKafkaConnectSpecFluent.JvmOptionsNested<A> withNewJvmOptionsLike(JvmOptions item);
    public AbstractKafkaConnectSpecFluent.JvmOptionsNested<A> editJvmOptions();
    public AbstractKafkaConnectSpecFluent.JvmOptionsNested<A> editOrNewJvmOptions();
    public AbstractKafkaConnectSpecFluent.JvmOptionsNested<A> editOrNewJvmOptionsLike(JvmOptions item);
    
/**
 * This method has been deprecated, please use method buildMetricsConfig instead.
 * @return The buildable object.
 */
@Deprecated public MetricsConfig getMetricsConfig();
    public MetricsConfig buildMetricsConfig();
    public A withMetricsConfig(MetricsConfig metricsConfig);
    public Boolean hasMetricsConfig();
    public A withJmxPrometheusExporterMetricsConfig(JmxPrometheusExporterMetrics jmxPrometheusExporterMetricsConfig);
    public AbstractKafkaConnectSpecFluent.JmxPrometheusExporterMetricsConfigNested<A> withNewJmxPrometheusExporterMetricsConfig();
    public AbstractKafkaConnectSpecFluent.JmxPrometheusExporterMetricsConfigNested<A> withNewJmxPrometheusExporterMetricsConfigLike(JmxPrometheusExporterMetrics item);
    public A addToMetrics(String key,Object value);
    public A addToMetrics(Map<String,Object> map);
    public A removeFromMetrics(String key);
    public A removeFromMetrics(Map<String,Object> map);
    public Map<String,Object> getMetrics();
    public <K extends Object,V extends Object>A withMetrics(Map<String,Object> metrics);
    public Boolean hasMetrics();
    
/**
 * This method has been deprecated, please use method buildTracing instead.
 * @return The buildable object.
 */
@Deprecated public Tracing getTracing();
    public Tracing buildTracing();
    public A withTracing(Tracing tracing);
    public Boolean hasTracing();
    public A withJaegerTracing(JaegerTracing jaegerTracing);
    public AbstractKafkaConnectSpecFluent.JaegerTracingNested<A> withNewJaegerTracing();
    public AbstractKafkaConnectSpecFluent.JaegerTracingNested<A> withNewJaegerTracingLike(JaegerTracing item);
    public Affinity getAffinity();
    public A withAffinity(Affinity affinity);
    public Boolean hasAffinity();
    public A addToTolerations(int index,Toleration item);
    public A setToTolerations(int index,Toleration item);
    public A addToTolerations(Toleration... items);
    public A addAllToTolerations(Collection<Toleration> items);
    public A removeFromTolerations(Toleration... items);
    public A removeAllFromTolerations(Collection<Toleration> items);
    public java.util.List<Toleration> getTolerations();
    public Toleration getToleration(int index);
    public Toleration getFirstToleration();
    public Toleration getLastToleration();
    public Toleration getMatchingToleration(Predicate<Toleration> predicate);
    public Boolean hasMatchingToleration(Predicate<Toleration> predicate);
    public A withTolerations(java.util.List<Toleration> tolerations);
    public A withTolerations(Toleration... tolerations);
    public Boolean hasTolerations();
    public A addNewToleration(String effect,String key,String operator,Long tolerationSeconds,String value);
    
/**
 * This method has been deprecated, please use method buildTemplate instead.
 * @return The buildable object.
 */
@Deprecated public KafkaConnectTemplate getTemplate();
    public KafkaConnectTemplate buildTemplate();
    public A withTemplate(KafkaConnectTemplate template);
    public Boolean hasTemplate();
    public AbstractKafkaConnectSpecFluent.TemplateNested<A> withNewTemplate();
    public AbstractKafkaConnectSpecFluent.TemplateNested<A> withNewTemplateLike(KafkaConnectTemplate item);
    public AbstractKafkaConnectSpecFluent.TemplateNested<A> editTemplate();
    public AbstractKafkaConnectSpecFluent.TemplateNested<A> editOrNewTemplate();
    public AbstractKafkaConnectSpecFluent.TemplateNested<A> editOrNewTemplateLike(KafkaConnectTemplate item);
    
/**
 * This method has been deprecated, please use method buildExternalConfiguration instead.
 * @return The buildable object.
 */
@Deprecated public ExternalConfiguration getExternalConfiguration();
    public ExternalConfiguration buildExternalConfiguration();
    public A withExternalConfiguration(ExternalConfiguration externalConfiguration);
    public Boolean hasExternalConfiguration();
    public AbstractKafkaConnectSpecFluent.ExternalConfigurationNested<A> withNewExternalConfiguration();
    public AbstractKafkaConnectSpecFluent.ExternalConfigurationNested<A> withNewExternalConfigurationLike(ExternalConfiguration item);
    public AbstractKafkaConnectSpecFluent.ExternalConfigurationNested<A> editExternalConfiguration();
    public AbstractKafkaConnectSpecFluent.ExternalConfigurationNested<A> editOrNewExternalConfiguration();
    public AbstractKafkaConnectSpecFluent.ExternalConfigurationNested<A> editOrNewExternalConfigurationLike(ExternalConfiguration item);
    public interface ExternalLoggingNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ExternalLoggingFluent<AbstractKafkaConnectSpecFluent.ExternalLoggingNested<N>> {

            public N and();
            public N endExternalLogging();    }


    public interface InlineLoggingNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,InlineLoggingFluent<AbstractKafkaConnectSpecFluent.InlineLoggingNested<N>> {

            public N and();
            public N endInlineLogging();    }


    public interface LivenessProbeNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ProbeFluent<AbstractKafkaConnectSpecFluent.LivenessProbeNested<N>> {

            public N and();
            public N endLivenessProbe();    }


    public interface ReadinessProbeNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ProbeFluent<AbstractKafkaConnectSpecFluent.ReadinessProbeNested<N>> {

            public N and();
            public N endReadinessProbe();    }


    public interface JmxOptionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaJmxOptionsFluent<AbstractKafkaConnectSpecFluent.JmxOptionsNested<N>> {

            public N and();
            public N endJmxOptions();    }


    public interface JvmOptionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,JvmOptionsFluent<AbstractKafkaConnectSpecFluent.JvmOptionsNested<N>> {

            public N and();
            public N endJvmOptions();    }


    public interface JmxPrometheusExporterMetricsConfigNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,JmxPrometheusExporterMetricsFluent<AbstractKafkaConnectSpecFluent.JmxPrometheusExporterMetricsConfigNested<N>> {

            public N and();
            public N endJmxPrometheusExporterMetricsConfig();    }


    public interface JaegerTracingNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,JaegerTracingFluent<AbstractKafkaConnectSpecFluent.JaegerTracingNested<N>> {

            public N and();
            public N endJaegerTracing();    }


    public interface TemplateNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaConnectTemplateFluent<AbstractKafkaConnectSpecFluent.TemplateNested<N>> {

            public N and();
            public N endTemplate();    }


    public interface ExternalConfigurationNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ExternalConfigurationFluent<AbstractKafkaConnectSpecFluent.ExternalConfigurationNested<N>> {

            public N and();
            public N endExternalConfiguration();    }


}
